@@ -78,13 +78,7 @@ CConfig::CConfig(const char* path, const Hyprlang::SConfigOptions& options_) : i
             throw "File does not exist";
     }
 
-    impl->envVariables.clear();
-    for (char** env = environ; *env; ++env) {
-        const std::string ENVVAR   = *env ? *env : "";
-        const auto        VARIABLE = ENVVAR.substr(0, ENVVAR.find_first_of('='));
-        const auto        VALUE    = ENVVAR.substr(ENVVAR.find_first_of('=') + 1);
-        impl->envVariables.push_back({VARIABLE, VALUE});
-    }
+    impl->recheckEnv();
 
     std::ranges::sort(impl->envVariables, [&](const auto& a, const auto& b) { return a.name.length() > b.name.length(); });
 
@@ -358,9 +352,13 @@ std::pair<bool, CParseResult> CConfig::configSetValueSafe(const std::string& com
                     found = true;
             }
 
+            // probably a handler
+            if (!valueName.contains(":"))
+                return {false, result};
+
             if (!found) {
                 for (auto& sc : impl->specialCategories) {
-                    if (!valueName.starts_with(sc->name))
+                    if (!valueName.starts_with(sc->name + ":"))
                         continue;
 
                     if (!sc->isStatic && std::string{std::any_cast<const char*>(sc->values[sc->key].getValue())} != impl->currentSpecialKey)
@@ -372,7 +370,7 @@ std::pair<bool, CParseResult> CConfig::configSetValueSafe(const std::string& com
                     if (VALUEIT != sc->values.end())
                         found = true;
                     else if (sc->descriptor->dontErrorOnMissing)
-                        return {true, result}; // will return a success, cuz we want to ignore missing
+                        return {false, result}; // will return a success, cuz we want to ignore missing
 
                     break;
                 }
@@ -528,6 +526,16 @@ CParseResult CConfig::parseVariable(const std::string& lhs, const std::string& r
     return result;
 }
 
+void CConfigImpl::recheckEnv() {
+    envVariables.clear();
+    for (char** env = environ; *env; ++env) {
+        const std::string ENVVAR   = *env ? *env : "";
+        const auto        VARIABLE = ENVVAR.substr(0, ENVVAR.find_first_of('='));
+        const auto        VALUE    = ENVVAR.substr(ENVVAR.find_first_of('=') + 1);
+        envVariables.push_back({VARIABLE, VALUE});
+    }
+}
+
 SVariable* CConfigImpl::getVariable(const std::string& name) {
     for (auto& v : envVariables) {
         if (v.name == name)
@@ -927,6 +935,10 @@ CParseResult CConfig::parse() {
     return fileParseResult;
 }
 
+void CConfig::changeRootPath(const char* path) {
+    impl->path = path;
+}
+
 CParseResult CConfig::parseRawStream(const std::string& stream) {
     CParseResult      result;
 
@@ -1030,13 +1042,13 @@ CParseResult CConfig::parseFile(const char* file) {
 }
 
 CParseResult CConfig::parseDynamic(const char* line) {
-    auto ret = parseLine(line, true);
+    auto ret                     = parseLine(line, true);
     impl->currentSpecialCategory = nullptr;
     return ret;
 }
 
 CParseResult CConfig::parseDynamic(const char* command, const char* value) {
-    auto ret = parseLine(std::string{command} + "=" + std::string{value}, true);
+    auto ret                     = parseLine(std::string{command} + "=" + std::string{value}, true);
     impl->currentSpecialCategory = nullptr;
     return ret;
 }
@@ -1044,7 +1056,8 @@ CParseResult CConfig::parseDynamic(const char* command, const char* value) {
 void CConfig::clearState() {
     impl->categories.clear();
     impl->parseError = "";
-    impl->variables  = impl->envVariables;
+    impl->recheckEnv();
+    impl->variables = impl->envVariables;
     std::erase_if(impl->specialCategories, [](const auto& e) { return !e->isStatic; });
 }
 
